==> apimodule-1.0.5.tar.gz: lib/msimpersaa/response/diklat_response.dart <==
class DiklatResponse {
  bool con;
  String msg;
  DiklatResults results;

  DiklatResponse({this.con, this.msg, this.results});

  DiklatResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    results = json['results'] != null
        ? DiklatResults.fromJson(json['results'])
        : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.toJson();
    }
    return data;
  }
}

class DiklatResults {
  List<Diklat> diklatStruktural;
  List<Diklat> diklatFungsional;
  List<Diklat> diklatTeknis;

  DiklatResults(
      {this.diklatStruktural, this.diklatFungsional, this.diklatTeknis});

  DiklatResults.fromJson(Map<String, dynamic> json) {
    if (json['diklat_struktural'] != null) {
      diklatStruktural = <Diklat>[];
      json['diklat_struktural'].forEach((v) {
        diklatStruktural.add(Diklat.fromJson(v));
      });
    }
    if (json['diklat_fungsional'] != null) {
      diklatFungsional = <Diklat>[];
      json['diklat_fungsional'].forEach((v) {
        diklatFungsional.add(Diklat.fromJson(v));
      });
    }
    if (json['diklat_teknis'] != null) {
      diklatTeknis = <Diklat>[];
      json['diklat_teknis'].forEach((v) {
        diklatTeknis.add(Diklat.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    if (this.diklatStruktural != null) {
      data['diklat_struktural'] =
          this.diklatStruktural.map((v) => v.toJson()).toList();
    }
    if (this.diklatFungsional != null) {
      data['diklat_fungsional'] =
          this.diklatFungsional.map((v) => v.toJson()).toList();
    }
    if (this.diklatTeknis != null) {
      data['diklat_teknis'] = this.diklatTeknis.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Diklat {
  int id;
  String nomorSttb;
  String tanggalSttb;
  String namaDiklat;
  String jenisDiklat;
  String tempatDiklat;
  String penyelenggara;
  String angkatan;
  String documen;
  String pathFile;

  Diklat(
      {this.id,
      this.nomorSttb,
      this.tanggalSttb,
      this.namaDiklat,
      this.jenisDiklat,
      this.tempatDiklat,
      this.penyelenggara,
      this.angkatan,
      this.documen,
      this.pathFile});

  Diklat.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nomorSttb = json['nomor_sttb'];
    tanggalSttb = json['tanggal_sttb'];
    namaDiklat = json['nama_diklat'];
    jenisDiklat = json['jenis_diklat'];
    tempatDiklat = json['tempat_diklat'];
    penyelenggara = json['penyelenggara'];
    angkatan = json['angkatan'];
    documen = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nomor_sttb'] = this.nomorSttb;
    data['tanggal_sttb'] = this.tanggalSttb;
    data['nama_diklat'] = this.namaDiklat;
    data['jenis_diklat'] = this.jenisDiklat;
    data['tempat_diklat'] = this.tempatDiklat;
    data['penyelenggara'] = this.penyelenggara;
    data['angkatan'] = this.angkatan;
    data['dokumen'] = this.documen;
    data['path_file'] = this.pathFile;
    return data;
  }
}

==> apimodule-1.1.5.tar.gz: lib/msimpersaa/response/diklat_response.dart <==
class DiklatResponse {
  bool con;
  String msg;
  DiklatResults results;

  DiklatResponse({this.con, this.msg, this.results});

  DiklatResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    results = json['results'] != null
        ? DiklatResults.fromJson(json['results'])
        : null;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.toJson();
    }
    return data;
  }
}

class DiklatResults {
  List<Diklat> diklatStruktural;
  List<Diklat> diklatFungsional;
  List<Diklat> diklatTeknis;

  DiklatResults(
      {this.diklatStruktural, this.diklatFungsional, this.diklatTeknis});

  DiklatResults.fromJson(Map<String, dynamic> json) {
    if (json['diklat_struktural'] != null) {
      diklatStruktural = <Diklat>[];
      json['diklat_struktural'].forEach((v) {
        diklatStruktural.add(Diklat.fromJson(v));
      });
    }
    if (json['diklat_fungsional'] != null) {
      diklatFungsional = <Diklat>[];
      json['diklat_fungsional'].forEach((v) {
        diklatFungsional.add(Diklat.fromJson(v));
      });
    }
    if (json['diklat_teknis'] != null) {
      diklatTeknis = <Diklat>[];
      json['diklat_teknis'].forEach((v) {
        diklatTeknis.add(Diklat.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    if (this.diklatStruktural != null) {
      data['diklat_struktural'] =
          this.diklatStruktural.map((v) => v.toJson()).toList();
    }
    if (this.diklatFungsional != null) {
      data['diklat_fungsional'] =
          this.diklatFungsional.map((v) => v.toJson()).toList();
    }
    if (this.diklatTeknis != null) {
      data['diklat_teknis'] = this.diklatTeknis.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class Diklat {
  int id;
  String nomorSttb;
  String tanggalSttb;
  String namaDiklat;
  String jenisDiklat;
  String tempatDiklat;
  String penyelenggara;
  String angkatan;
  String document;
  String pathFile;

  Diklat(
      {this.id,
      this.nomorSttb,
      this.tanggalSttb,
      this.namaDiklat,
      this.jenisDiklat,
      this.tempatDiklat,
      this.penyelenggara,
      this.angkatan,
      this.document,
      this.pathFile});

  Diklat.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nomorSttb = json['nomor_sttb'];
    tanggalSttb = json['tanggal_sttb'];
    namaDiklat = json['nama_diklat'];
    jenisDiklat = json['jenis_diklat'];
    tempatDiklat = json['tempat_diklat'];
    penyelenggara = json['penyelenggara'];
    angkatan = json['angkatan'];
    document = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nomor_sttb'] = this.nomorSttb;
    data['tanggal_sttb'] = this.tanggalSttb;
    data['nama_diklat'] = this.namaDiklat;
    data['jenis_diklat'] = this.jenisDiklat;
    data['tempat_diklat'] = this.tempatDiklat;
    data['penyelenggara'] = this.penyelenggara;
    data['angkatan'] = this.angkatan;
    data['dokumen'] = this.document;
    data['path_file'] = this.pathFile;
    return data;
  }
}
